package com.parkingLot.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSONObject;
import com.parkingLot.dto.CarInfoDTO;
import com.parkingLot.dto.DataDTO;
import com.parkingLot.dto.Response.CommonResponse;
import com.parkingLot.service.RemoteCallService;
import com.parkingLot.utils.SignatureUtil;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.Map;

/**
 * @author wu
 * @since 2024/12/13 09:11
 */
@Service
public class RemoteCallServiceImpl implements RemoteCallService {

    @Value("${url}")
    private String url;

    @Value("${appId}")
    private String appId;

    @Value("${appSecret}")
    private String appSecret;

    @Value("${parkId}")
    private String parkId;

    /**
     * 通用请求
     *
     * @param serviceCode 方法名
     * @return 通用请求
     */
    private JSONObject getMap(String serviceCode) {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("appId", appId);
        jsonObject.put("parkId", parkId);
        jsonObject.put("ts", System.currentTimeMillis());
        jsonObject.put("reqId", IdUtil.fastSimpleUUID());
        jsonObject.put("serviceCode", serviceCode);
        return jsonObject;
    }

    /**
     * 区域剩余车位查询
     *
     * @return 响应类
     */
    @Override
    public CommonResponse GetAreaFreeSpaceNum() {
        CommonResponse response = new CommonResponse();
        JSONObject jsonObject = getMap("getAreaFreeSpaceNum");
        String key = SignatureUtil.paramsSign(jsonObject, appSecret);
        jsonObject.put("key", key);
        String body = jsonObject.toJSONString();
        String result = HttpRequest.post(url + "api/wec/GetAreaFreeSpaceNum")
                .header("version", "1.0.0")
                .header("accept-language", "zh-CN")
                .body(body).execute().body();
        Map<String, Object> map = JSONUtil.parseObj(result);
        Object dataObj = map.get("data");
        response.setResMsg((String) map.get("resMsg"));
        response.setResCode((String) map.get("resCode"));
        if (dataObj == null || dataObj == "" || StrUtil.isEmpty(String.valueOf(dataObj))) {
            return response;
        }
        Map<String, Object> data = JSONUtil.parseObj(dataObj);
        DataDTO dataDTO = BeanUtil.toBeanIgnoreCase(data, DataDTO.class, false);
        response.setData(dataDTO);
        return response;
    }

    /**
     * 根据车牌查询在场数据
     *
     * @param plateNo 车牌号
     * @return 响应类
     */
    @Override
    public CommonResponse GetCarInfoByPlateNo(String plateNo) {
        CommonResponse response = new CommonResponse();
        JSONObject jsonObject = getMap("getCarInfoByPlateNo");
        jsonObject.put("plateNo", plateNo);
        String key = SignatureUtil.paramsSign(jsonObject, appSecret);
        jsonObject.put("key", key);
        String body = jsonObject.toJSONString();
        String result = HttpRequest.post(url + "api/wec/GetCarInfoByPlateNo")
                .header("version", "1.0.0")
                .header("accept-language", "zh-CN")
                .body(body).execute().body();
        Map<String, Object> map = JSONUtil.parseObj(result);
        Object dataObj = map.get("data");
        response.setResMsg((String) map.get("resMsg"));
        response.setResCode((String) map.get("resCode"));
        if (dataObj == null || dataObj == "" || StrUtil.isEmpty(String.valueOf(dataObj))) {
            return response;
        }
        Map<String, Object> data = JSONUtil.parseObj(dataObj);
        CarInfoDTO dataDTO = BeanUtil.toBeanIgnoreCase(data, CarInfoDTO.class, false);
        response.setData(dataDTO);
        return response;
    }
}
